//---------------------------------------------------------------------
//  Algorithmic Conjurings @ http://www.coyotegulch.com
//
//  maze_recursive.h (libcoyote)
//
//  Maze generation and exploration tools
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 2001, 2002, 2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

#if !defined(LIBCOYOTE_MAZE_RECURSIVE_H)
#define LIBCOYOTE_MAZE_RECURSIVE_H

#include "libcoyote/maze.h"
#include "libcoyote/mtprng.h"

namespace libcoyote
{
    //! Implements a recursive, back-tracking maze architect
    /*!
        A concrete implementation of a maze architect, using a
        recursive, back-tracking algorithm.
    */
    class recursive_maze_architect : public libcoyote::maze::architect
    {
    public:
        //! Constructor
        /*!
            Creates a new architect, initializing its random-number
            generator with the given seed.
            \param a_seed - Seed for random number generator
        */
        recursive_maze_architect(unsigned long a_seed)
            : m_prng(a_seed) // initialize random number generator
        {
            // nada
        }


        //! Creates a floor plan for a maze
        /*!
            "Carves" a maze using a recursive backtracking algorithm
            \param a_target - The <i>maze</i> that will be "architected".
        */
        virtual void create_floor_plan(libcoyote::maze & a_target);

    private:
        // random number generator
        mtprng m_prng;
    };
}

#endif
