//---------------------------------------------------------------------
//  Algorithmic Conjurings @ http://www.libcoyote.com
//
//  realutil.cpp (libcoyote)
//
//  A collection of useful functions for working with numbers.
//---------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//
//  This notice applies *only* to this specific expression of this
//  algorithm, and does not imply ownership or invention of the
//  implemented algorithm.
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1991-2002, 2003 Scott Robert Ladd. All rights reserved.
//  All rights reserved, except as noted herein.
//
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.libcoyote.com
//  
//-----------------------------------------------------------------------

// Standard C++ library
#include <cfloat>

// libcoyote
#include "libcoyote/realutil.h"

using namespace libcoyote;

// lowest common denominator
unsigned long libcoyote::lcm(unsigned long x, unsigned long y)
{
    unsigned long s, l;

    if (x == y)
        return x;

    if (x < y)
    {
        s = x;
        l = y;
    }
    else
    {
        l = x;
        s = y;
    }

    return (l / gcd(s,l)) * s;
}

// greatest common multiple
unsigned long libcoyote::gcd(unsigned long x, unsigned long y)
{
    unsigned long temp;

    while (y != 0ul)
    {
        temp = x % y;
        x = y;
        y = temp;
    }

    return x;
}


